@@ -25,6 +25,7 @@ class MetaAware(ABC):
     _command: Dict[Type[MetaAware], ff.TypeOfCommand] = {}
     _query: Dict[Type[MetaAware], ff.TypeOfQuery] = {}
     _endpoints: Dict[Type[MetaAware], List[ff.Endpoint]] = {}
+    _timers: Dict[Type[MetaAware], ff.Timer] = {}
     _agent: Optional[str] = None
     _middleware_config: Optional[Dict] = None
     _annotations: Dict[Type[MetaAware], List[ff.ConfigurationAnnotation]] = {}
@@ -59,6 +60,10 @@ class MetaAware(ABC):
     def set_command(cls, command: ff.TypeOfCommand):
         cls._command[cls] = command
 
+    @classmethod
+    def set_timer(cls, timer: ff.Timer):
+        cls._timers[cls] = timer
+
     @classmethod
     def set_query(cls, query: ff.TypeOfQuery):
         cls._query[cls] = query
@@ -71,6 +76,10 @@ class MetaAware(ABC):
     def is_command_handler(cls):
         return cls in cls._command
 
+    @classmethod
+    def has_timer(cls):
+        return cls in cls._timers
+
     @classmethod
     def is_query_handler(cls):
         return cls in cls._query
@@ -91,6 +100,10 @@ class MetaAware(ABC):
     def get_command(cls):
         return cls._command[cls]
 
+    @classmethod
+    def get_timer(cls):
+        return cls._timers[cls]
+
     @classmethod
     def get_query(cls):
         return cls._query[cls]
